@@ -105,6 +105,7 @@ class Scheduler(threading.Thread):
         self.manager = manager
         self.triggers = []
         self.running_triggers = {}
+        self.waiting_triggers = set()
         self._stop = threading.Event()
 
     def start(self):
@@ -133,16 +134,20 @@ class Scheduler(threading.Thread):
         with self.triggers_lock:
             for trigger in self.triggers:
                 if trigger.should_run:
-                    if trigger.uid in self.running_triggers:
-                        log.error('Not firing schedule %r. Tasks from last run have still not finished.' % trigger)
-                        log.error('You may need to increase the interval for this schedule.')
+                    if trigger in self.running_triggers:
+                        if trigger not in self.waiting_triggers:
+                            log.error('Not firing schedule %r. Tasks from last run have still not finished.' % trigger)
+                            log.error('You may need to increase the interval for this schedule.')
+                            self.waiting_triggers.add(trigger)
                         continue
                     options = dict(trigger.options)
                     # If the user has specified all tasks with '*', don't add tasks option at all, so that manual
                     # tasks are not executed
                     if trigger.tasks != ['*']:
                         options['tasks'] = trigger.tasks
-                    self.running_triggers[trigger.uid] = self.manager.execute(options=options, priority=5)
+                    if trigger in self.waiting_triggers:
+                        self.waiting_triggers.remove(trigger)
+                    self.running_triggers[trigger] = self.manager.execute(options=options, priority=5)
                     trigger.trigger()
 
     def run(self):
@@ -174,15 +179,6 @@ class Trigger(object):
         self._get_db_last_run()
         self.schedule_next_run()
 
-    @property
-    def uid(self):
-        """A unique id which describes this trigger."""
-        # Determine uniqueness based on interval,
-        hashval = md5(str(sorted(self.interval)))
-        # and tasks run on that interval.
-        hashval.update(','.join(self.tasks).encode('utf-8'))
-        return hashval.hexdigest()
-
     # Handles getting and setting interval in form validated by config
     @property
     def interval(self):
@@ -248,7 +244,7 @@ class Trigger(object):
     def _get_db_last_run(self):
         session = Session()
         try:
-            db_trigger = session.query(DBTrigger).get(self.uid)
+            db_trigger = session.query(DBTrigger).get(hash(self))
             if db_trigger:
                 self.last_run = db_trigger.last_run
                 log.debug('loaded last_run from the database')
@@ -258,9 +254,9 @@ class Trigger(object):
     def _set_db_last_run(self):
         session = Session()
         try:
-            db_trigger = session.query(DBTrigger).get(self.uid)
+            db_trigger = session.query(DBTrigger).get(hash(self))
             if not db_trigger:
-                db_trigger = DBTrigger(self.uid)
+                db_trigger = DBTrigger(hash(self))
                 session.add(db_trigger)
             db_trigger.last_run = self.last_run
             session.commit()
@@ -268,6 +264,13 @@ class Trigger(object):
             session.close()
         log.debug('recorded last_run to the database')
 
+    def __hash__(self):
+        """A unique id which describes this trigger."""
+        return hash(tuple(sorted(self.interval.iteritems())) + tuple(sorted(self.tasks)))
+
+    def __eq__(self, other):
+        return (self.interval, self.tasks) == (other.interval, other.tasks)
+
     def __repr__(self):
         return 'Trigger(tasks=%r, amount=%r, unit=%r)' % (self.tasks, self.amount, self.unit)
 
